# -*- coding: utf-8 -*- #
#
# Copyright 2018 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Package marker file."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.core.util import importing
from googlecloudsdk.core.util import lazy_regex

# Lazy loader doesn't work in some environments, such as par files
try:
  importing.lazy_load_module('googlecloudsdk.api_lib.app.yaml_parsing')
except ImportError:
  pass

lazy_regex.initialize_lazy_compile()
